==> aliyun-python-sdk-imm-1.16.7.tar.gz: aliyun-python-sdk-imm-1.16.7/aliyunsdkimm/request/v20170906/FindSimilarFacesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class FindSimilarFacesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'FindSimilarFaces','imm')
		self.set_method('POST')

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_MinSimilarity(self):
		return self.get_query_params().get('MinSimilarity')

	def set_MinSimilarity(self,MinSimilarity):
		self.add_query_param('MinSimilarity',MinSimilarity)

	def get_ResponseFormat(self):
		return self.get_query_params().get('ResponseFormat')

	def set_ResponseFormat(self,ResponseFormat):
		self.add_query_param('ResponseFormat',ResponseFormat)

	def get_Limit(self):
		return self.get_query_params().get('Limit')

	def set_Limit(self,Limit):
		self.add_query_param('Limit',Limit)

	def get_FaceId(self):
		return self.get_query_params().get('FaceId')

	def set_FaceId(self,FaceId):
		self.add_query_param('FaceId',FaceId)

	def get_ImageUri(self):
		return self.get_query_params().get('ImageUri')

	def set_ImageUri(self,ImageUri):
		self.add_query_param('ImageUri',ImageUri)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)

==> aliyun-python-sdk-imm-1.17.0.tar.gz: aliyun-python-sdk-imm-1.17.0/aliyunsdkimm/request/v20170906/FindSimilarFacesRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class FindSimilarFacesRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'imm', '2017-09-06', 'FindSimilarFaces')
		self.set_method('POST')

	def get_Project(self):
		return self.get_query_params().get('Project')

	def set_Project(self,Project):
		self.add_query_param('Project',Project)

	def get_MinSimilarity(self):
		return self.get_query_params().get('MinSimilarity')

	def set_MinSimilarity(self,MinSimilarity):
		self.add_query_param('MinSimilarity',MinSimilarity)

	def get_ResponseFormat(self):
		return self.get_query_params().get('ResponseFormat')

	def set_ResponseFormat(self,ResponseFormat):
		self.add_query_param('ResponseFormat',ResponseFormat)

	def get_Limit(self):
		return self.get_query_params().get('Limit')

	def set_Limit(self,Limit):
		self.add_query_param('Limit',Limit)

	def get_FaceId(self):
		return self.get_query_params().get('FaceId')

	def set_FaceId(self,FaceId):
		self.add_query_param('FaceId',FaceId)

	def get_ImageUri(self):
		return self.get_query_params().get('ImageUri')

	def set_ImageUri(self,ImageUri):
		self.add_query_param('ImageUri',ImageUri)

	def get_SetId(self):
		return self.get_query_params().get('SetId')

	def set_SetId(self,SetId):
		self.add_query_param('SetId',SetId)
